@@ -6,6 +6,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
+#include <stdbool.h>
 #include <string.h>
 #include <ctype.h>
 #include <unistd.h>
@@ -30,9 +31,8 @@ int      vlistInqVarMissvalUsed(int vlistID, int varID);
 #  define DBL_IS_EQUAL(x,y) (DBL_IS_NAN(x)||DBL_IS_NAN(y)?(DBL_IS_NAN(x)&&DBL_IS_NAN(y)?1:0):!(x < y || y < x))
 #endif
 
-#ifndef IS_EQUAL
+#ifndef IS_NOT_EQUAL
 #  define IS_NOT_EQUAL(x,y) (x < y || y < x)
-#  define IS_EQUAL(x,y)     (!IS_NOT_EQUAL(x,y))
 #endif
 
 #ifndef HOST_ENDIANNESS
@@ -102,8 +102,14 @@ void version(void)
 #if defined (_OPENMP)
   fprintf(stderr, " OpenMP");
 #endif
-#if  defined  (HAVE_NETCDF4)
+#if  defined(HAVE_NETCDF4)
   fprintf(stderr, " NC4");
+#if  defined(HAVE_NC4HDF5)
+  fprintf(stderr, "/HDF5");
+#if  defined(HAVE_NC4HDF5_THREADSAFE)
+  fprintf(stderr, "/threadsafe");
+#endif
+#endif
 #endif
 #if  defined  (HAVE_LIBNC_DAP)
   fprintf(stderr, " OPeNDAP");
@@ -111,9 +117,6 @@ void version(void)
 #if defined (HAVE_LIBSZ)
   fprintf(stderr, " SZ");
 #endif
-#if defined (HAVE_LIBZ)
-  fprintf(stderr, " Z");
-#endif
 #if defined (HAVE_LIBJASPER)
   fprintf(stderr, " JASPER");
 #endif
