@@ -17,14 +17,14 @@
 const char *cdfLibraryVersion(void)
 {
 #if  defined  (HAVE_LIBNETCDF)
-  return (nc_inq_libvers());
+  return nc_inq_libvers();
 #else
-  return ("library undefined");
+  return "library undefined";
 #endif
 }
 
-#if  defined(HAVE_LIBHDF5)
-#if defined(__cplusplus)
+#if  defined(HAVE_H5GET_LIBVERSION)
+#if  defined(__cplusplus)
 extern "C" {
 #endif
   int H5get_libversion(unsigned *, unsigned *, unsigned *);
@@ -35,17 +35,20 @@ extern "C" {
 
 const char *hdfLibraryVersion(void)
 {
-#if  defined(HAVE_LIBHDF5)
+#if  defined(HAVE_H5GET_LIBVERSION)
   static char hdf_libvers[256];
   unsigned majnum, minnum, relnum;
 
   H5get_libversion(&majnum, &minnum, &relnum);
 
-  sprintf(hdf_libvers, "%u.%u.%u", majnum, minnum, relnum);
-
-  return (hdf_libvers);
+#if  defined(HAVE_NC4HDF5_THREADSAFE)
+  sprintf(hdf_libvers, "%u.%u.%u threadsafe", majnum, minnum, relnum);
 #else
-  return ("library undefined");
+  sprintf(hdf_libvers, "%u.%u.%u", majnum, minnum, relnum);
+#endif
+  return hdf_libvers;
+#else
+  return "library undefined";
 #endif
 }
 
@@ -67,28 +70,26 @@ void cdfComment(int ncid)
 {
   static char comment[256] = "Climate Data Interface version ";
   static int init = 0;
-  char *blank;
-  int size = 0;
 
   if ( ! init )
     {
       init = 1;
-      blank = strchr(cdiLibraryVersion(), ' ');
-      if ( blank ) size = blank - cdiLibraryVersion();
+      const char *libvers = cdiLibraryVersion();
+      const char *blank = strchr(libvers, ' ');
+      size_t size = blank ? (size_t)(blank - libvers) : 0;
 
-      if ( size == 0 || ! isdigit((int) *cdiLibraryVersion()) )
+      if ( size == 0 || ! isdigit((int) *libvers) )
 	strcat(comment, "??");
       else
-	strncat(comment, cdiLibraryVersion(), size);
-      strcat(comment, " (http://code.zmaw.de/projects/cdi)");
+	strncat(comment, libvers, size);
+      strcat(comment, " (http://mpimet.mpg.de/cdi)");
     }
 
   cdf_put_att_text(ncid, NC_GLOBAL, "CDI", strlen(comment), comment);
-  cdf_put_att_text(ncid, NC_GLOBAL, "Conventions", 6, "CF-1.4");
 }
 #endif
 
-int cdfOpenFile(const char *filename, const char *mode, int *filetype)
+static int cdfOpenFile(const char *filename, const char *mode, int *filetype)
 {
   int ncid = -1;
 #if  defined  (HAVE_LIBNETCDF)
@@ -127,7 +128,8 @@ int cdfOpenFile(const char *filename, const char *mode, int *filetype)
 	  else if ( *filetype == FILETYPE_NC4C ) writemode |= NC_NETCDF4 | NC_CLASSIC_MODEL;
 #endif
 	  cdf_create(filename, writemode, &ncid);
-	  cdfComment(ncid);
+	  if ( CDI_Version_Info ) cdfComment(ncid);
+          cdf_put_att_text(ncid, NC_GLOBAL, "Conventions", 6, "CF-1.4");
 	  break;
 	case 'a':
 	  cdf_open(filename, NC_WRITE, &ncid);
@@ -138,24 +140,23 @@ int cdfOpenFile(const char *filename, const char *mode, int *filetype)
     }
 #endif
 
-  return (ncid);
+  return ncid;
 }
 
 
 int cdfOpen(const char *filename, const char *mode)
 {
-  int fileID = 0;
   int filetype = FILETYPE_NC;
 
   if ( CDF_Debug )
     Message("Open %s with mode %c", filename, *mode);
 
-  fileID = cdfOpenFile(filename, mode, &filetype);
+  int fileID = cdfOpenFile(filename, mode, &filetype);
 
   if ( CDF_Debug )
     Message("File %s opened with id %d", filename, fileID);
 
-  return (fileID);
+  return fileID;
 }
 
 
@@ -186,7 +187,7 @@ int cdfOpen64(const char *filename, const char *mode)
       fileID = CDI_ELIBNAVAIL;
     }
 
-  return (fileID);
+  return fileID;
 }
 
 
@@ -214,11 +215,11 @@ int cdf4Open(const char *filename, const char *mode, int *filetype)
       fileID = CDI_ELIBNAVAIL;
     }
 
-  return (fileID);
+  return fileID;
 }
 
 
-void cdfCloseFile(int fileID)
+static void cdfCloseFile(int fileID)
 {
 #if  defined  (HAVE_LIBNETCDF)
   cdf_close(fileID);
