@@ -1,13 +1,13 @@
 #include <stdlib.h>
 
+#include "cdi_int.h"
 #include "dmemory.h"
 #include "file.h"
 #include "stream_fcommon.h"
 
-void streamFCopyRecord(stream_t *streamptr2, stream_t *streamptr1,
-                       const char *container_name)
-{
 
+void streamFCopyRecord(stream_t *streamptr2, stream_t *streamptr1, const char *container_name)
+{
   int fileID1 = streamptr1->fileID;
   int fileID2 = streamptr2->fileID;
 
@@ -20,7 +20,7 @@ void streamFCopyRecord(stream_t *streamptr2, stream_t *streamptr1,
   if (fileSetPos(fileID1, recpos, SEEK_SET) != 0)
     Error("Cannot seek input file for %s record copy!", container_name);
 
-  char *buffer = xmalloc(recsize);
+  char *buffer = (char *) Malloc(recsize);
 
   if (fileRead(fileID1, buffer, recsize) != recsize)
     Error("Failed to read record from %s file for copying!", container_name);
@@ -28,7 +28,7 @@ void streamFCopyRecord(stream_t *streamptr2, stream_t *streamptr1,
   if (fileWrite(fileID2, buffer, recsize) != recsize)
     Error("Failed to write record to %s file when copying!", container_name);
 
-  free(buffer);
+  Free(buffer);
 }
 
 /*
