@@ -2,6 +2,7 @@
 #  include "config.h"
 #endif
 
+#include <limits.h>
 #include <stdio.h>
 #include <string.h>
 
@@ -27,13 +28,14 @@ void recordInitEntry(record_t *record)
   record->varID    = CDI_UNDEFID;
   record->levelID  = CDI_UNDEFID;
   memset(record->varname, 0, sizeof(record->varname));
+  memset(&record->tiles, 0, sizeof(record->tiles));
 }
 
 
 int recordNewEntry(stream_t *streamptr, int tsID)
 {
-  int recordID = 0;
-  int recordSize = streamptr->tsteps[tsID].recordSize;
+  size_t recordID = 0;
+  size_t recordSize = (size_t)streamptr->tsteps[tsID].recordSize;
   record_t *records = streamptr->tsteps[tsID].records;
   /*
     Look for a free slot in record.
@@ -41,44 +43,33 @@ int recordNewEntry(stream_t *streamptr, int tsID)
   */
   if ( ! recordSize )
     {
-      int i;
       recordSize = 1;   /*  <<<<----  */
-      records = (record_t *)xmalloc((size_t)recordSize * sizeof (record_t));
-      if ( records == NULL )
-	{
-          Message("recordSize = %d", recordSize);
-	  SysError("Allocation of records failed");
-	}
+      records = (record_t *) Malloc(recordSize * sizeof (record_t));
 
-      for ( i = 0; i < recordSize; i++ )
+      for ( size_t i = 0; i < recordSize; i++ )
 	records[i].used = CDI_UNDEFID;
     }
   else
     {
-      while ( recordID < recordSize )
-	{
-	  if ( records[recordID].used == CDI_UNDEFID ) break;
-	  recordID++;
-	}
+      while ( recordID < recordSize
+              && records[recordID].used != CDI_UNDEFID )
+        ++recordID;
     }
   /*
     If the table overflows, double its size.
   */
   if ( recordID == recordSize )
     {
-      int i;
+      if (recordSize <= INT_MAX / 2)
+        recordSize *= 2;
+      else if (recordSize < INT_MAX)
+        recordSize = INT_MAX;
+      else
+        Error("Cannot handle this many records!\n");
+      records = (record_t *) Realloc(records,
+                                     recordSize * sizeof (record_t));
 
-      recordSize = 2*recordSize;
-      records    = (record_t *)xrealloc(records,
-                                        (size_t)recordSize * sizeof (record_t));
-      if ( records == NULL )
-	{
-          Message("recordSize = %d", recordSize);
-	  SysError("Reallocation of records failed");
-	}
-      recordID = recordSize/2;
-
-      for ( i = recordID; i < recordSize; i++ )
+      for ( size_t i = recordID; i < recordSize; i++ )
 	records[i].used = CDI_UNDEFID;
     }
 
@@ -86,16 +77,16 @@ int recordNewEntry(stream_t *streamptr, int tsID)
 
   records[recordID].used = 1;
 
-  streamptr->tsteps[tsID].recordSize = recordSize;
+  streamptr->tsteps[tsID].recordSize = (int)recordSize;
   streamptr->tsteps[tsID].records    = records;
 
-  return (recordID);
+  return (int)recordID;
 }
 
 static
 void cdiInitRecord(stream_t *streamptr)
 {
-  streamptr->record = (Record *) malloc(sizeof(Record));
+  streamptr->record = (Record *) Malloc(sizeof(Record));
 
   streamptr->record->param      = 0;
   streamptr->record->level      = 0;
@@ -116,7 +107,6 @@ void streamInqRecord(int streamID, int *varID, int *levelID)
   check_parg(levelID);
 
   stream_t *streamptr = stream_to_pointer(streamID);
-  stream_check_ptr(__func__, streamptr);
 
   cdiDefAccesstype(streamID, TYPE_REC);
 
@@ -136,7 +126,8 @@ void streamInqRecord(int streamID, int *varID, int *levelID)
   *varID   = streamptr->tsteps[tsID].records[recID].varID;
   int lindex = streamptr->tsteps[tsID].records[recID].levelID;
 
-  *levelID = streamptr->vars[*varID].lindex[lindex];
+  int isub = subtypeInqActiveIndex(streamptr->vars[*varID].subtypeID);
+  *levelID = streamptr->vars[*varID].recordTable[isub].lindex[lindex];
 
   if ( CDI_Debug )
     Message("tsID = %d, recID = %d, varID = %d, levelID = %d\n", tsID, recID, *varID, *levelID);
@@ -162,7 +153,6 @@ The function streamDefRecord defines the meta-data of the next record.
 void streamDefRecord(int streamID, int varID, int levelID)
 {
   stream_t *streamptr = stream_to_pointer(streamID);
-  stream_check_ptr(__func__, streamptr);
 
   int tsID = streamptr->curTsID;
 
@@ -178,7 +168,7 @@ void streamDefRecord(int streamID, int varID, int levelID)
   int gridID  = vlistInqVarGrid(vlistID, varID);
   int zaxisID = vlistInqVarZaxis(vlistID, varID);
   int param   = vlistInqVarParam(vlistID, varID);
-  int level   = (int) zaxisInqLevel(zaxisID, levelID);
+  int level   = (int)(zaxisInqLevel(zaxisID, levelID));
 
   streamptr->record->varID    = varID;
   streamptr->record->levelID  = levelID;
@@ -228,144 +218,13 @@ void streamDefRecord(int streamID, int varID, int levelID)
 }
 
 
-void streamReadRecord(int streamID, double *data, int *nmiss)
-{
-  check_parg(data);
-  check_parg(nmiss);
-
-  stream_t *streamptr = stream_to_pointer(streamID);
-  stream_check_ptr(__func__, streamptr);
-
-  *nmiss = 0;
-
-  switch (streamptr->filetype)
-    {
-#if  defined  (HAVE_LIBGRIB)
-    case FILETYPE_GRB:
-    case FILETYPE_GRB2:
-      grbReadRecord(streamptr, data, nmiss);
-      break;
-#endif
-#if  defined  (HAVE_LIBSERVICE)
-    case FILETYPE_SRV:
-      srvReadRecord(streamptr, data, nmiss);
-      break;
-#endif
-#if  defined  (HAVE_LIBEXTRA)
-    case FILETYPE_EXT:
-      extReadRecord(streamptr, data, nmiss);
-      break;
-#endif
-#if  defined  (HAVE_LIBIEG)
-    case FILETYPE_IEG:
-      iegReadRecord(streamptr, data, nmiss);
-      break;
-#endif
-#if  defined  (HAVE_LIBNETCDF)
-    case FILETYPE_NC:
-    case FILETYPE_NC2:
-    case FILETYPE_NC4:
-    case FILETYPE_NC4C:
-      cdfReadRecord(streamptr, data, nmiss);
-      break;
-#endif
-    default:
-      {
-	Error("%s support not compiled in!", strfiletype(streamptr->filetype));
-	break;
-      }
-    }
-}
-
-static void
-stream_write_record(int streamID, int memtype, const void *data, int nmiss)
-{
-  check_parg(data);
-
-  stream_t *streamptr = stream_to_pointer(streamID);
-  stream_check_ptr(__func__, streamptr);
-
-  switch (streamptr->filetype)
-    {
-#if  defined  (HAVE_LIBGRIB)
-    case FILETYPE_GRB:
-    case FILETYPE_GRB2:
-      grb_write_record(streamptr, memtype, data, nmiss);
-      break;
-#endif
-#if  defined  (HAVE_LIBSERVICE)
-    case FILETYPE_SRV:
-      if ( memtype == MEMTYPE_FLOAT ) Error("srvWriteRecord not implemented for memtype float!");
-      srvWriteRecord(streamptr, (const double *)data);
-      break;
-#endif
-#if  defined  (HAVE_LIBEXTRA)
-    case FILETYPE_EXT:
-      if ( memtype == MEMTYPE_FLOAT ) Error("extWriteRecord not implemented for memtype float!");
-      extWriteRecord(streamptr, (const double *)data);
-      break;
-#endif
-#if  defined  (HAVE_LIBIEG)
-    case FILETYPE_IEG:
-      if ( memtype == MEMTYPE_FLOAT ) Error("iegWriteRecord not implemented for memtype float!");
-      iegWriteRecord(streamptr, (const double *)data);
-      break;
-#endif
-#if  defined  (HAVE_LIBNETCDF)
-    case FILETYPE_NC:
-    case FILETYPE_NC2:
-    case FILETYPE_NC4:
-    case FILETYPE_NC4C:
-      {
-	cdf_write_record(streamptr, memtype, data, nmiss);
-	break;
-      }
-#endif
-    default:
-      {
-	Error("%s support not compiled in!", strfiletype(streamptr->filetype));
-	break;
-      }
-    }
-}
-
-/*
-@Function  streamWriteRecord
-@Title     Write a horizontal slice of a variable
-
-@Prototype void streamWriteRecord(int streamID, const double *data, int nmiss)
-@Parameter
-    @Item  streamID  Stream ID, from a previous call to @fref{streamOpenWrite}.
-    @Item  data      Pointer to a block of double precision floating point data values to be written.
-    @Item  nmiss     Number of missing values.
-
-@Description
-The function streamWriteRecord writes the values of a horizontal slice (record) of a variable to an open dataset.
-The values are converted to the external data type of the variable, if necessary.
-@EndFunction
-*/
-void streamWriteRecord(int streamID, const double *data, int nmiss)
-{
-  stream_write_record(streamID, MEMTYPE_DOUBLE, (const void *) data, nmiss);
-}
-
-void streamWriteRecordF(int streamID, const float *data, int nmiss)
-{
-  stream_write_record(streamID, MEMTYPE_FLOAT, (const void *) data, nmiss);
-}
-
-
 void streamCopyRecord(int streamID2, int streamID1)
 {
-  stream_t *streamptr1 = stream_to_pointer(streamID1);
-  stream_t *streamptr2 = stream_to_pointer(streamID2);
-
-  stream_check_ptr(__func__, streamptr1);
-  stream_check_ptr(__func__, streamptr2);
-
-  int filetype1 = streamptr1->filetype;
-  int filetype2 = streamptr2->filetype;
-  int filetype  = FILETYPE_UNDEF;
+  stream_t *streamptr1 = stream_to_pointer(streamID1),
+    *streamptr2 = stream_to_pointer(streamID2);
+  int filetype1 = streamptr1->filetype,
+    filetype2 = streamptr2->filetype,
+    filetype  = FILETYPE_UNDEF;
 
   if ( filetype1 == filetype2 ) filetype = filetype2;
   else
@@ -438,8 +297,8 @@ void cdi_create_records(stream_t *streamptr, int tsID)
   unsigned nrecords, maxrecords;
   record_t *records;
 
-  tsteps_t* sourceTstep = streamptr->tsteps;
-  tsteps_t* destTstep = sourceTstep + tsID;
+  tsteps_t *sourceTstep = streamptr->tsteps;
+  tsteps_t *destTstep = sourceTstep + tsID;
 
   if ( destTstep->records ) return;
 
@@ -450,7 +309,8 @@ void cdi_create_records(stream_t *streamptr, int tsID)
       maxrecords = 0;
       int nvars = streamptr->nvars;
       for ( int varID = 0; varID < nvars; varID++)
-	maxrecords += (unsigned)streamptr->vars[varID].nlevs;
+        for (int isub=0; isub<streamptr->vars[varID].subtypeSize; isub++)
+          maxrecords += (unsigned)streamptr->vars[varID].recordTable[isub].nlevs;
     }
   else
     {
@@ -480,7 +340,7 @@ void cdi_create_records(stream_t *streamptr, int tsID)
   //  printf("tsID, nrecords %d %d\n", tsID, nrecords);
 
   if ( maxrecords > 0 )
-    records = (record_t *) malloc(maxrecords * sizeof(record_t));
+    records = (record_t *) Malloc(maxrecords*sizeof(record_t));
   else
     records = NULL;
 
@@ -499,7 +359,7 @@ void cdi_create_records(stream_t *streamptr, int tsID)
 
       for ( unsigned recID = 0; recID < maxrecords; recID++ )
 	{
-          record_t* curRecord = &sourceTstep->records[recID];
+          record_t *curRecord = &sourceTstep->records[recID];
           destTstep->records[recID].used = curRecord->used;
           if ( curRecord->used != CDI_UNDEFID && curRecord->varID != -1 ) /* curRecord->varID = -1 for write mode !!! */
             {
