@@ -31,12 +31,14 @@ typedef int MPI_Comm;
 #include "pio_write.h"
 
 #include "simple_model_helper.h"
+#include "cdi_uuid.h"
 
 enum {
   ntfiles     = 2,
   nproma = 16,
 };
 
+
 static void
 modelRegionCompute(double region[], int nlev, int nlat, int nlon,
                    const int chunkStart[3], const int chunkSize[3],
@@ -57,15 +59,11 @@ modelRegionCompute(double region[], int nlev, int nlat, int nlon,
     for (unsigned j = 0; j < n; ++j)
       for (unsigned i = 0; i < m; ++i)
         region[k * kstride + j * jstride + i]
-          = sign_flat(round((cos(2.0 * M_PI
-                                 * (lons[(i + is + (unsigned)tsID)
-                                         %(unsigned)nlon] - lons[0])
-                                 / (lons[nlon-1] - lons[0]))
-                             * sin(2.0 * M_PI
-                                   * (lats[(j + js + k + ks)%(unsigned)nlat]
-                                      - lats[0])
-                                   / (lats[nlat-1] - lats[0]))
-                             ) * mscale)) * mrscale;
+          = dg_wobble((lons[(i + is + (unsigned)tsID)%(unsigned)nlon] - lons[0])
+                      / (lons[nlon-1] - lons[0]),
+                      (lats[(j + js + k + ks)%(unsigned)nlat] - lats[0])
+                      / (lats[nlat-1] - lats[0]),
+                      mscale, mrscale);
 }
 
 #ifdef USE_MPI
@@ -78,7 +76,7 @@ modelRun(struct model_config setup, MPI_Comm comm)
 {
   static const char * const fname_prefix        = "example";
 
-  struct
+  struct varDesc_t
   {
     size_t size;
     int nlev, zaxisID, id, code;
@@ -90,8 +88,8 @@ modelRun(struct model_config setup, MPI_Comm comm)
 #endif
   } *varDesc;
   int gridID, taxisID, vlistID, streamID, tsID, tfID = 0;
-  int i, nmiss = 0;
-  double *lons, *lats, *levs;
+  enum { nmiss = 0 };
+  double *restrict lons, *restrict lats, *restrict levs;
   double *var = NULL, *varslice = NULL;
   double mscale, mrscale;
   time_t current_time;
@@ -99,7 +97,7 @@ modelRun(struct model_config setup, MPI_Comm comm)
   int rank = 0;
   char filename[1024];
   int nlon = setup.nlon, nlat = setup.nlat;
-  int nVars = setup.nvars;
+  size_t nVars = setup.nvars > 0 ? (size_t)setup.nvars : 0;
   size_t varslice_size = 0;
 #if USE_MPI
   int comm_size = 1;
@@ -110,11 +108,13 @@ modelRun(struct model_config setup, MPI_Comm comm)
 #if USE_MPI
   xmpi ( MPI_Comm_rank ( comm, &rank ));
   xmpi ( MPI_Comm_size ( comm, &comm_size ));
+#else
+  (void)comm;
 #endif
 
   if (rank == 0 && setup.compute_checksum)
     {
-      var = xmalloc((size_t)nlon * (size_t)nlat
+      var = (double *)Malloc((size_t)nlon * (size_t)nlat
                     * (size_t)setup.max_nlev * sizeof(var[0]));
     }
 
@@ -132,7 +132,7 @@ modelRun(struct model_config setup, MPI_Comm comm)
       rank_coord[0] = rank % npart[0],
         rank_coord[1] = rank / npart[0];
     }
-  blk_displ = xmalloc((size_t)setup.max_nlev * sizeof (blk_displ[0]) * 2);
+  blk_displ = Malloc((size_t)setup.max_nlev * sizeof (blk_displ[0]) * 2);
   blk_lens = blk_displ + setup.max_nlev;
 #endif
 
@@ -141,24 +141,34 @@ modelRun(struct model_config setup, MPI_Comm comm)
   gridID = gridCreate ( GRID_LONLAT, nlon*nlat );
   gridDefXsize ( gridID, nlon );
   gridDefYsize ( gridID, nlat );
-  lons = xmalloc((size_t)nlon * sizeof (lons[0]));
-  for (i = 0; i < nlon; ++i)
+  lons = (double *)Malloc((size_t)nlon * sizeof (lons[0]));
+  for (size_t i = 0; i < (size_t)nlon; ++i)
     lons[i] = ((double)(i * 360))/nlon;
-  lats = xmalloc((size_t)nlat * sizeof (lats[0]));
-  for (i = 0; i < nlat; ++i)
+  lats = (double *)Malloc((size_t)nlat * sizeof (lats[0]));
+  for (size_t i = 0; i < (size_t)nlat; ++i)
     lats[i] = ((double)(i * 180))/nlat - 90.0;
   gridDefXvals ( gridID, lons );
   gridDefYvals ( gridID, lats );
-
-  levs = xmalloc((size_t)setup.max_nlev * sizeof (levs[0]));
-  for (i = 0; i < setup.max_nlev; ++i)
-    levs[i] = 101300.0
-      - 3940.3 * (exp(1.3579 * (double)(i)/(setup.max_nlev - 1)) - 1.0);
-
+  if (setup.create_uuid)
+  {
+    unsigned char uuid[CDI_UUID_SIZE];
+    if (rank == 0)
+      cdiCreateUUID(uuid);
+#if USE_MPI
+    MPI_Bcast(uuid, CDI_UUID_SIZE, MPI_UNSIGNED_CHAR, 0, comm);
+#endif
+    gridDefUUID(gridID, uuid);
+  }
+  levs = (double *)Malloc((size_t)setup.max_nlev * sizeof (levs[0]));
+  {
+    double lscale = 1.0/(double)(setup.max_nlev - 1);
+    for (size_t i = 0; i < (size_t)setup.max_nlev; ++i)
+      levs[i] = 101300.0 - 13000.0 * expm1(2.173 * (double)i * lscale);
+  }
   vlistID = vlistCreate ();
 
-  varDesc = xmalloc((size_t)nVars * sizeof (varDesc[0]));
-  for (int varIdx = 0; varIdx < nVars; varIdx++ )
+  varDesc = (struct varDesc_t *)Malloc(nVars * sizeof (varDesc[0]));
+  for (size_t varIdx = 0; varIdx < nVars; varIdx++ )
     {
       int varLevs = (int)random()%4;
       switch (varLevs)
@@ -181,9 +191,24 @@ modelRun(struct model_config setup, MPI_Comm comm)
             varDesc[varIdx].zaxisID = varDesc[i].zaxisID;
             goto zaxisIDset;
           }
-      varDesc[varIdx].zaxisID
-        = zaxisCreate(ZAXIS_PRESSURE, varDesc[varIdx].nlev);
-      zaxisDefLevels(varDesc[varIdx].zaxisID, levs);
+      if (varLevs == 1)
+        varDesc[varIdx].zaxisID = zaxisCreate(ZAXIS_SURFACE, 1);
+      else
+        {
+          varDesc[varIdx].zaxisID
+            = zaxisCreate(ZAXIS_PRESSURE, varDesc[varIdx].nlev);
+          zaxisDefLevels(varDesc[varIdx].zaxisID, levs);
+        }
+      if (setup.create_uuid)
+      {
+        unsigned char uuid[16];
+        if (rank == 0)
+          cdiCreateUUID(uuid);
+#if USE_MPI
+        MPI_Bcast(uuid, CDI_UUID_SIZE, MPI_UNSIGNED_CHAR, 0, comm);
+#endif
+        zaxisDefUUID(varDesc[varIdx].zaxisID, uuid);
+      }
       zaxisIDset:
       varDesc[varIdx].id
         = vlistDefVar(vlistID, gridID, varDesc[varIdx].zaxisID, TIME_VARIABLE);
@@ -191,6 +216,18 @@ modelRun(struct model_config setup, MPI_Comm comm)
         = (size_t)nlon * (size_t)nlat * (size_t)varDesc[varIdx].nlev;
 #ifdef USE_MPI
       {
+        for (size_t i = 0; i < varIdx; ++i)
+          if (varDesc[i].nlev == varLevs)
+            {
+              varDesc[varIdx].redist4gather = varDesc[i].redist4gather;
+              varDesc[varIdx].partDesc = varDesc[i].partDesc;
+              for (size_t j = 0; j < 2; ++j)
+                {
+                  varDesc[varIdx].start[j] = varDesc[i].start[j];
+                  varDesc[varIdx].chunkSize[j] = varDesc[i].chunkSize[j];
+                }
+              goto partDescriptionSet;
+            }
         int start[2], chunkSize[3], varSize[2] = { nlon, nlat };
         for (size_t i = 0; i < 2; ++i)
           {
@@ -207,13 +244,6 @@ modelRun(struct model_config setup, MPI_Comm comm)
         Xt_int varSizeXt[3] = { (Xt_int)nlon, (Xt_int)nlat, (Xt_int)varLevs };
         chunkSize[2] = varLevs;
         Xt_int varStartXt[3] = { start[0], start[1], 0 };
-        for (int i = 0; i < varIdx; ++i)
-          if (varDesc[i].nlev == varLevs)
-            {
-              varDesc[varIdx].redist4gather = varDesc[i].redist4gather;
-              varDesc[varIdx].partDesc = varDesc[i].partDesc;
-              goto gatherRedistSet;
-            }
         Xt_idxlist part_idxlist
           = xt_idxsection_new(0, (varLevs > 1 ? 3 : 2), varSizeXt,
                               chunkSize, varStartXt),
@@ -232,7 +262,7 @@ modelRun(struct model_config setup, MPI_Comm comm)
             Xt_xmap xmap4gather
               = xt_xmap_all2all_new(part_idxlist, gather_idxlist, comm);
             xt_idxlist_delete(gather_idxlist);
-            struct Xt_offset_ext *src_blocks = xmalloc((size_t)varLevs
+            struct Xt_offset_ext *src_blocks = Malloc((size_t)varLevs
                                                        * sizeof (*src_blocks));
             struct Xt_offset_ext dst_block = { .start = 0,
                                                .size = nlon * nlat * varLevs,
@@ -249,13 +279,13 @@ modelRun(struct model_config setup, MPI_Comm comm)
               = xt_redist_p2p_ext_new(xmap4gather,
                                       varLevs, src_blocks, 1, &dst_block,
                                       MPI_DOUBLE);
-            free(src_blocks);
+            Free(src_blocks);
             xt_xmap_delete(xmap4gather);
           }
-        gatherRedistSet: ;
+        partDescriptionSet: ;
       }
 #endif
-      varDesc[varIdx].code = 129 + varIdx;
+      varDesc[varIdx].code = GRIB_USERDEF + (int)varIdx;
       vlistDefVarCode(vlistID, varDesc[varIdx].id, varDesc[varIdx].code);
       vlistDefVarDatatype(vlistID, varDesc[varIdx].id, setup.datatype);
     }
@@ -274,7 +304,7 @@ modelRun(struct model_config setup, MPI_Comm comm)
 
   for ( tfID = 0; tfID < ntfiles; tfID++ )
     {
-      for (int varIdx = 0; varIdx < nVars; ++varIdx)
+      for (size_t varIdx = 0; varIdx < nVars; ++varIdx)
         varDesc[varIdx].checksum_state = 0;
       if ( tfID > 0 )
 	{
@@ -294,15 +324,23 @@ modelRun(struct model_config setup, MPI_Comm comm)
 	  taxisDefVdate(taxisID, vdatetime[1]);
 	  taxisDefVtime(taxisID, vdatetime[0]);
 	  streamDefTimestep ( streamID, tsID );
-	  for (int varID = 0; varID < nVars; ++varID)
+          if (setup.filetype == FILETYPE_EXT)
+            {
+              /* EXTRA doesn't store time, only date
+               * set the value to 0 before checksumming, because a
+               * time field of 0 is what reading an EXTRA file will
+               * return */
+              vdatetime[0] = 0;
+            }
+	  for (size_t varIdx = 0; varIdx < nVars; ++varIdx)
 	    {
-              size_t varLevs = (size_t)varDesc[varID].nlev;
+              size_t varLevs = (size_t)varDesc[varIdx].nlev;
 #ifdef USE_MPI
-              int start[3] = { varDesc[varID].start[0],
-                               varDesc[varID].start[1],
+              int start[3] = { varDesc[varIdx].start[0],
+                               varDesc[varIdx].start[1],
                                0 };
-              int chunk[3] = { varDesc[varID].chunkSize[0],
-                               varDesc[varID].chunkSize[1],
+              int chunk[3] = { varDesc[varIdx].chunkSize[0],
+                               varDesc[varIdx].chunkSize[1],
                                (int)varLevs };
 #else
               int chunk[3] = { nlon, nlat, (int)varLevs };
@@ -313,7 +351,7 @@ modelRun(struct model_config setup, MPI_Comm comm)
                    / (size_t)nproma) * (size_t)nproma * varLevs;
               if (varslice_size < chunkSize)
                 {
-                  varslice = xrealloc(varslice, chunkSize * sizeof (var[0]));
+                  varslice = (double *)Realloc(varslice, chunkSize * sizeof (var[0]));
                   varslice_size = chunkSize;
                 }
               modelRegionCompute(varslice, (int)varLevs, nlat, nlon,
@@ -322,7 +360,7 @@ modelRun(struct model_config setup, MPI_Comm comm)
               if (setup.compute_checksum)
                 {
 #if USE_MPI
-                  xt_redist_s_exchange1(varDesc[varID].redist4gather,
+                  xt_redist_s_exchange1(varDesc[varIdx].redist4gather,
                                         varslice, var);
                   size_t layerSize = (size_t)(chunk[0] * chunk[1]);
                   size_t nblk = (layerSize + nproma - 1)/nproma - 1;
@@ -349,26 +387,26 @@ modelRun(struct model_config setup, MPI_Comm comm)
                 }
               if (rank == 0 && setup.compute_checksum)
                 {
-                  memcrc_r(&varDesc[varID].checksum_state,
+                  memcrc_r(&varDesc[varIdx].checksum_state,
                            (const unsigned char *)vdatetime,
                            sizeof (vdatetime));
-                  memcrc_r(&varDesc[varID].checksum_state,
+                  memcrc_r(&varDesc[varIdx].checksum_state,
                            (const unsigned char *)var,
-                           varDesc[varID].size * sizeof (var[0]));
+                           varDesc[varIdx].size * sizeof (var[0]));
                 }
 
 #ifdef USE_MPI
-	      streamWriteScatteredVarPart(streamID, varDesc[varID].id,
+	      streamWriteScatteredVarPart(streamID, varDesc[varIdx].id,
                                           varslice,
                                           (int)varLevs, blk_lens, blk_displ,
-                                          nmiss, varDesc[varID].partDesc);
+                                          nmiss, varDesc[varIdx].partDesc);
 #else
-	      streamWriteVar(streamID, varDesc[varID].id, var, nmiss);
+	      streamWriteVar(streamID, varDesc[varIdx].id, var, nmiss);
 #endif
 	    }
           current_time += 86400;
 #ifdef USE_MPI
-	  pioWriteTimestep ( tsID, vdate, vtime );
+	  pioWriteTimestep();
 #endif
 	}
       if (rank == 0 && setup.compute_checksum)
@@ -381,7 +419,7 @@ modelRun(struct model_config setup, MPI_Comm comm)
                 perror("failed to open table file");
                 exit(EXIT_FAILURE);
               }
-            for (i = 0; i < nVars; ++i)
+            for (size_t i = 0; i < nVars; ++i)
               {
                 uint32_t cksum;
                 int code;
@@ -402,37 +440,37 @@ modelRun(struct model_config setup, MPI_Comm comm)
           }
         }
     }
-  free(varslice);
+  Free(varslice);
 #ifdef USE_MPI
   pioEndTimestepping ();
 #endif
   streamClose ( streamID );
   vlistDestroy ( vlistID );
   taxisDestroy ( taxisID );
-  for (int varID = 0; varID < nVars; varID++ )
+  for (size_t varIdx = 0; varIdx < nVars; varIdx++ )
     {
-      int zID = varDesc[varID].zaxisID;
+      int zID = varDesc[varIdx].zaxisID;
       if (zID != CDI_UNDEFID)
         {
           zaxisDestroy(zID);
 #if USE_MPI
-          xt_idxlist_delete(varDesc[varID].partDesc);
-          xt_redist_delete(varDesc[varID].redist4gather);
+          xt_idxlist_delete(varDesc[varIdx].partDesc);
+          xt_redist_delete(varDesc[varIdx].redist4gather);
 #endif
-          for (int j = varID + 1; j < nVars; ++j)
+          for (size_t j = varIdx + 1; j < nVars; ++j)
             if (zID == varDesc[j].zaxisID)
               varDesc[j].zaxisID = CDI_UNDEFID;
         }
     }
   gridDestroy ( gridID );
-  free(var);
+  Free(var);
 #if USE_MPI
-  free(blk_displ);
+  Free(blk_displ);
 #endif
-  free(varDesc);
-  free(levs);
-  free(lats);
-  free(lons);
+  Free(varDesc);
+  Free(levs);
+  Free(lats);
+  Free(lons);
 }
 
 #ifdef USE_MPI
@@ -490,7 +528,7 @@ findPartition2D(int npart[2], int num_parts)
         }
       } while (pattern <= lastPattern);
     }
-  free(factors);
+  Free(factors);
 }
 #endif
 
