@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2014 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
+  Copyright (C) 2003-2016 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -100,21 +100,21 @@ void *Intgridtraj(void *argument)
   nvars    = vlistNvars(vlistID1);
   nrecords = vlistNrecs(vlistID1);
 
-  recVarID   = malloc(nrecords*sizeof(int));
-  recLevelID = malloc(nrecords*sizeof(int));
+  recVarID   = (int*) Malloc(nrecords*sizeof(int));
+  recLevelID = (int*) Malloc(nrecords*sizeof(int));
 
   gridsize = vlistGridsizeMax(vlistID1);
-  array = malloc(gridsize*sizeof(double));
+  array = (double*) Malloc(gridsize*sizeof(double));
 
-  vardata1 = malloc(nvars*sizeof(double*));
-  vardata2 = malloc(nvars*sizeof(double*));
+  vardata1 = (double**) Malloc(nvars*sizeof(double*));
+  vardata2 = (double**) Malloc(nvars*sizeof(double*));
 
   for ( varID = 0; varID < nvars; varID++ )
     {
       gridsize = gridInqSize(vlistInqVarGrid(vlistID1, varID));
       nlevel   = zaxisInqSize(vlistInqVarZaxis(vlistID1, varID));
-      vardata1[varID] = malloc(gridsize*nlevel*sizeof(double));
-      vardata2[varID] = malloc(gridsize*nlevel*sizeof(double));
+      vardata1[varID] = (double*) Malloc(gridsize*nlevel*sizeof(double));
+      vardata2[varID] = (double*) Malloc(gridsize*nlevel*sizeof(double));
     }
 
   gridID2 = gridCreate(GRID_TRAJECTORY, 1);
@@ -246,14 +246,14 @@ void *Intgridtraj(void *argument)
 
   for ( varID = 0; varID < nvars; varID++ )
     {
-      free(vardata1[varID]);
-      free(vardata2[varID]);
+      Free(vardata1[varID]);
+      Free(vardata2[varID]);
     }
-  free(vardata1);
-  free(vardata2);
-  if ( array )  free(array);
+  Free(vardata1);
+  Free(vardata2);
+  if ( array )  Free(array);
 
   cdoFinish();
 
-  return (0);
+  return 0;
 }
