@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2014 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
+  Copyright (C) 2003-2016 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -32,16 +32,16 @@
 
 
 static
-void interp_lev(int gridsize, double missval, double *vardata1, double *vardata2,
-		int nlev2, int *lev_idx1, int *lev_idx2, double *lev_wgt1, double *lev_wgt2)
+void vert_interp_lev(int gridsize, double missval, double *vardata1, double *vardata2,
+		     int nlev2, int *lev_idx1, int *lev_idx2, double *lev_wgt1, double *lev_wgt2)
 {
-  int i, ilev;
+  int i;
   int idx1, idx2;
   double wgt1, wgt2;
   double w1, w2;
   double *var1L1, *var1L2, *var2;
 
-  for ( ilev = 0; ilev < nlev2; ++ilev )
+  for ( int ilev = 0; ilev < nlev2; ++ilev )
     {
       idx1 = lev_idx1[ilev];
       idx2 = lev_idx2[ilev];
@@ -55,7 +55,7 @@ void interp_lev(int gridsize, double missval, double *vardata1, double *vardata2
       var1L2 = vardata1+gridsize*idx2;
 
 #if defined(_OPENMP)
-#pragma omp parallel for shared(gridsize, var2, var1L1, var1L2, wgt1, wgt2, missval) private(i, w1, w2)
+#pragma omp parallel for default(none) shared(gridsize, var2, var1L1, var1L2, wgt1, wgt2, missval) private(w1, w2)
 #endif
       for ( i = 0; i < gridsize; ++i )
 	{
@@ -91,20 +91,20 @@ void interp_lev(int gridsize, double missval, double *vardata1, double *vardata2
 }
 
 static
-void gen_weights(int expol, int nlev1, double *lev1, int nlev2, double *lev2,
-		 int *lev_idx1, int *lev_idx2, double *lev_wgt1, double *lev_wgt2)
+void vert_gen_weights(int expol, int nlev1, double *lev1, int nlev2, double *lev2,
+		      int *lev_idx1, int *lev_idx2, double *lev_wgt1, double *lev_wgt2)
 {
-  int i1, i2;
-  double val1, val2 = 0;
+  int i1;
   int    idx1 = 0, idx2 = 0;
+  double val1, val2 = 0;
 
-  for ( i2 = 0; i2 < nlev2; ++i2 )
+  for ( int i2 = 0; i2 < nlev2; ++i2 )
     {
       for ( i1 = 1; i1 < nlev1; ++i1 )
 	{
 	  if ( lev1[i1-1] < lev1[i1] )
 	    {
-	      idx1 = i1 - 1;
+	      idx1 = i1-1;
 	      idx2 = i1;
 	    }
 	  else
@@ -162,60 +162,47 @@ void gen_weights(int expol, int nlev1, double *lev1, int nlev2, double *lev2,
 
 void *Intlevel(void *argument)
 {
-  int INTLEVEL, INTLEVELX;
-  int operatorID;
-  int streamID1, streamID2;
-  int vlistID1, vlistID2;
   int gridsize;
   int recID, nrecs;
   int i, offset;
-  int tsID, varID, levelID;
-  int nvars;
-  int nzaxis;
+  int varID, levelID;
   int nmiss;
-  int zaxisID1 = -1, zaxisID2;
+  int zaxisID1 = -1;
   int gridID, zaxisID;
-  int nlev1, nlev2, nlevel = 0, maxlev;
-  int lup, ldown;
-  int **varnmiss = NULL;
-  int *varinterp = NULL;
-  int *vars = NULL;
-  int expol = FALSE;
+  int nlevel = 0;
   double missval;
-  double *lev1 = NULL, *lev2 = NULL;
   double *single1, *single2;
-  double **vardata1 = NULL, **vardata2 = NULL;
-  int taxisID1, taxisID2;
-  int *lev_idx1, *lev_idx2;
-  double *lev_wgt1, *lev_wgt2;
-  LIST *flist = listNew(FLT_LIST);
 
   cdoInitialize(argument);
 
-  INTLEVEL   = cdoOperatorAdd("intlevel",  0, 0, NULL);
-  INTLEVELX  = cdoOperatorAdd("intlevelx", 0, 0, NULL);
+  int INTLEVEL   = cdoOperatorAdd("intlevel",  0, 0, NULL);
+  int INTLEVELX  = cdoOperatorAdd("intlevelx", 0, 0, NULL);
 
-  operatorID = cdoOperatorID();
+  UNUSED(INTLEVEL);
 
-  if ( operatorID == INTLEVELX ) expol = TRUE;
+  int operatorID = cdoOperatorID();
+
+  bool expol = false;
+  if ( operatorID == INTLEVELX ) expol = true;
 
   operatorInputArg("levels");
 
-  nlev2 = args2fltlist(operatorArgc(), operatorArgv(), flist);
-  lev2  = (double *) listArrayPtr(flist);
+  LIST *flist = listNew(FLT_LIST);
+  int nlev2 = args2fltlist(operatorArgc(), operatorArgv(), flist);
+  double *lev2  = (double *) listArrayPtr(flist);
 
   if ( cdoVerbose ) for ( i = 0; i < nlev2; ++i ) printf("lev2 %d: %g\n", i, lev2[i]);
 
-  streamID1 = streamOpenRead(cdoStreamName(0));
+  int streamID1 = streamOpenRead(cdoStreamName(0));
 
-  vlistID1 = streamInqVlist(streamID1);
-  vlistID2 = vlistDuplicate(vlistID1);
+  int vlistID1 = streamInqVlist(streamID1);
+  int vlistID2 = vlistDuplicate(vlistID1);
 
-  taxisID1 = vlistInqTaxis(vlistID1);
-  taxisID2 = taxisDuplicate(taxisID1);
+  int taxisID1 = vlistInqTaxis(vlistID1);
+  int taxisID2 = taxisDuplicate(taxisID1);
   vlistDefTaxis(vlistID2, taxisID2);
 
-  nzaxis  = vlistNzaxis(vlistID1);
+  int nzaxis  = vlistNzaxis(vlistID1);
   for ( i = 0; i < nzaxis; i++ )
     {
       zaxisID = vlistZaxis(vlistID1, i);
@@ -230,30 +217,30 @@ void *Intlevel(void *argument)
 
   if ( i == nzaxis ) cdoAbort("No processable variable found!");
 
-  nlev1 = nlevel;
-  lev1  = (double*) malloc((nlev1+2)*sizeof(double));
+  int nlev1 = nlevel;
+  double *lev1 = (double*) Malloc((nlev1+2)*sizeof(double));
   zaxisInqLevels(zaxisID1, lev1+1);
 
-  lup = FALSE;
-  ldown = FALSE;
+  bool lup = false;
+  bool ldown = false;
   for ( i = 1; i < nlev1; ++i )
     {
       if ( i == 1 )
 	{
 	  if ( lev1[i+1] > lev1[i] )
-	    lup = TRUE;
+	    lup = true;
 	  else if ( lev1[i+1] < lev1[i] )
-	    ldown = TRUE;	
+	    ldown = true;	
 	}
       else
 	{
 	  if ( lup )
 	    {
-	      if ( !(lev1[i+1] > lev1[i]) ) lup = FALSE;
+	      if ( !(lev1[i+1] > lev1[i]) ) lup = false;
 	    }
 	  else if ( ldown )
 	    {
-	      if ( !(lev1[i+1] < lev1[i]) ) ldown = FALSE;
+	      if ( !(lev1[i+1] < lev1[i]) ) ldown = false;
 	    }
 	}
     }
@@ -273,14 +260,14 @@ void *Intlevel(void *argument)
 
   if ( cdoVerbose ) for ( i = 0; i < nlev1+2; ++i ) printf("lev1 %d: %g\n", i, lev1[i]);
 
-  lev_idx1 = (int*) malloc(nlev2*sizeof(int));
-  lev_idx2 = (int*) malloc(nlev2*sizeof(int));
-  lev_wgt1 = (double*) malloc(nlev2*sizeof(double));
-  lev_wgt2 = (double*) malloc(nlev2*sizeof(double));
+  int *lev_idx1 = (int*) Malloc(nlev2*sizeof(int));
+  int *lev_idx2 = (int*) Malloc(nlev2*sizeof(int));
+  double *lev_wgt1 = (double*) Malloc(nlev2*sizeof(double));
+  double *lev_wgt2 = (double*) Malloc(nlev2*sizeof(double));
 
-  gen_weights(expol, nlev1+2, lev1, nlev2, lev2, lev_idx1, lev_idx2, lev_wgt1, lev_wgt2);
+  vert_gen_weights(expol, nlev1+2, lev1, nlev2, lev2, lev_idx1, lev_idx2, lev_wgt1, lev_wgt2);
 
-  zaxisID2 = zaxisCreate(zaxisInqType(zaxisID1), nlev2);
+  int zaxisID2 = zaxisCreate(zaxisInqType(zaxisID1), nlev2);
   zaxisDefLevels(zaxisID2, lev2);
   {
     char str[256];
@@ -301,19 +288,19 @@ void *Intlevel(void *argument)
     if ( zaxisID1 == vlistZaxis(vlistID1, i) )
       vlistChangeZaxisIndex(vlistID2, i, zaxisID2);
 
-  streamID2 = streamOpenWrite(cdoStreamName(1), cdoFiletype());
+  int streamID2 = streamOpenWrite(cdoStreamName(1), cdoFiletype());
 
   streamDefVlist(streamID2, vlistID2);
 
-  nvars = vlistNvars(vlistID1);
+  int nvars = vlistNvars(vlistID1);
 
-  vars      = (int*) malloc(nvars*sizeof(int));
-  vardata1  = (double**) malloc(nvars*sizeof(double*));
-  vardata2  = (double**) malloc(nvars*sizeof(double*));
-  varnmiss  = (int**) malloc(nvars*sizeof(int*));
-  varinterp = (int*) malloc(nvars*sizeof(int));
+  bool *vars = (bool*) Malloc(nvars*sizeof(bool));
+  bool *varinterp = (bool*) Malloc(nvars*sizeof(bool));
+  int **varnmiss = (int**) Malloc(nvars*sizeof(int*));
+  double **vardata1 = (double**) Malloc(nvars*sizeof(double*));
+  double **vardata2 = (double**) Malloc(nvars*sizeof(double*));
 
-  maxlev   = nlev1 > nlev2 ? nlev1 : nlev2;
+  int maxlev = nlev1 > nlev2 ? nlev1 : nlev2;
 
   for ( varID = 0; varID < nvars; varID++ )
     {
@@ -322,28 +309,28 @@ void *Intlevel(void *argument)
       gridsize = gridInqSize(gridID);
       nlevel   = zaxisInqSize(zaxisID);
 
-      vardata1[varID] = (double*) malloc(gridsize*nlevel*sizeof(double));
+      vardata1[varID] = (double*) Malloc(gridsize*nlevel*sizeof(double));
 
       if ( zaxisID == zaxisID1 )
 	{
-	  varinterp[varID] = TRUE;
-	  vardata2[varID]  = (double*) malloc(gridsize*nlev2*sizeof(double));
-	  varnmiss[varID]  = (int*) malloc(maxlev*sizeof(int));
+	  varinterp[varID] = true;
+	  vardata2[varID]  = (double*) Malloc(gridsize*nlev2*sizeof(double));
+	  varnmiss[varID]  = (int*) Malloc(maxlev*sizeof(int));
 	  memset(varnmiss[varID], 0, maxlev*sizeof(int));
 	}
       else
 	{
-	  varinterp[varID] = FALSE;
+	  varinterp[varID] = false;
 	  vardata2[varID]  = vardata1[varID];
-	  varnmiss[varID]  = (int*) malloc(nlevel*sizeof(int));
+	  varnmiss[varID]  = (int*) Malloc(nlevel*sizeof(int));
 	}
     }
 
 
-  tsID = 0;
+  int tsID = 0;
   while ( (nrecs = streamInqTimestep(streamID1, tsID)) )
     {
-      for ( varID = 0; varID < nvars; ++varID ) vars[varID] = FALSE;
+      for ( varID = 0; varID < nvars; ++varID ) vars[varID] = false;
 
       taxisCopyTimestep(taxisID2, taxisID1);
 
@@ -353,12 +340,11 @@ void *Intlevel(void *argument)
 	{
 	  streamInqRecord(streamID1, &varID, &levelID);
 	  gridsize = gridInqSize(vlistInqVarGrid(vlistID1, varID));
-	  nlevel   = zaxisInqSize(vlistInqVarZaxis(vlistID1, varID));
 	  offset   = gridsize*levelID;
 	  single1  = vardata1[varID] + offset;
 	  
 	  streamReadRecord(streamID1, single1, &varnmiss[varID][levelID]);
-	  vars[varID] = TRUE;
+	  vars[varID] = true;
 	}
 
       for ( varID = 0; varID < nvars; varID++ )
@@ -369,8 +355,8 @@ void *Intlevel(void *argument)
 	      missval  = vlistInqVarMissval(vlistID1, varID);
 	      gridsize = gridInqSize(gridID);
 
-	      interp_lev(gridsize, missval, vardata1[varID], vardata2[varID],
-			 nlev2, lev_idx1, lev_idx2, lev_wgt1, lev_wgt2);
+	      vert_interp_lev(gridsize, missval, vardata1[varID], vardata2[varID],
+			      nlev2, lev_idx1, lev_idx2, lev_wgt1, lev_wgt2);
 
 	      for ( levelID = 0; levelID < nlev2; levelID++ )
 		{
@@ -409,27 +395,27 @@ void *Intlevel(void *argument)
 
   for ( varID = 0; varID < nvars; varID++ )
     {
-      free(varnmiss[varID]);
-      free(vardata1[varID]);
-      if ( varinterp[varID] ) free(vardata2[varID]);
+      Free(varnmiss[varID]);
+      Free(vardata1[varID]);
+      if ( varinterp[varID] ) Free(vardata2[varID]);
     }
 
-  free(varinterp);
-  free(varnmiss);
-  free(vardata2);
-  free(vardata1);
-  free(vars);
+  Free(varinterp);
+  Free(varnmiss);
+  Free(vardata2);
+  Free(vardata1);
+  Free(vars);
 
-  free(lev_idx1);
-  free(lev_idx2);
-  free(lev_wgt1);
-  free(lev_wgt2);
+  Free(lev_idx1);
+  Free(lev_idx2);
+  Free(lev_wgt1);
+  Free(lev_wgt2);
 
-  if (lev1) free(lev1);
+  Free(lev1);
 
   listDelete(flist);
 
   cdoFinish();
 
-  return (0);
+  return 0;
 }
