@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2014 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
+  Copyright (C) 2003-2016 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -24,9 +24,9 @@
       Timselstat    timselmean         Time range mean
       Timselstat    timselavg          Time range average
       Timselstat    timselvar          Time range variance
-      Timselstat    timselvar1         Time range variance [Divisor is (n-1)]
+      Timselstat    timselvar1         Time range variance [Normalize by (n-1)]
       Timselstat    timselstd          Time range standard deviation
-      Timselstat    timselstd1         Time range standard deviation [Divisor is (n-1)]
+      Timselstat    timselstd1         Time range standard deviation [Normalize by (n-1)]
 */
 
 
@@ -38,30 +38,14 @@
 
 void *Timselstat(void *argument)
 {
-  int operatorID;
-  int operfunc;
-  int gridsize;
-  int vdate = 0, vtime = 0;
-  int vdate0 = 0, vtime0 = 0;
-  int vdate_lb = 0, vdate_ub = 0, date_lb = 0, date_ub = 0;
-  int vtime_lb = 0, vtime_ub = 0, time_lb = 0, time_ub = 0;
-  int nrecs = 0, nrecords;
+  int timestat_date = TIMESTAT_MEAN;
+  int nrecs = 0;
   int varID, levelID, recID;
   int tsID;
-  int otsID;
   int nsets;
   int i;
-  int streamID1, streamID2;
-  int vlistID1, vlistID2, taxisID1, taxisID2;
-  int taxis_has_bounds = FALSE;
   int nmiss;
-  int nvars, nlevel;
-  int ndates = 0, noffset = 0, nskip = 0, nargc;
-  int *recVarID, *recLevelID;
-  int lmean = FALSE, lvarstd = FALSE, lstd = FALSE;
-  double divisor;
-  field_t **vars1 = NULL, **vars2 = NULL, **samp1 = NULL;
-  field_t field;
+  int nlevel;
 
   cdoInitialize(argument);
 
@@ -75,53 +59,57 @@ void *Timselstat(void *argument)
   cdoOperatorAdd("timselstd",  func_std,  0, NULL);
   cdoOperatorAdd("timselstd1", func_std1, 0, NULL);
 
-  operatorID = cdoOperatorID();
-  operfunc = cdoOperatorF1(operatorID);
+  int operatorID = cdoOperatorID();
+  int operfunc = cdoOperatorF1(operatorID);
 
   operatorInputArg("nsets <noffset <nskip>>");
 
-  nargc = operatorArgc();
-
-  ndates = atoi(operatorArgv()[0]);
-  if ( nargc > 1 ) noffset = atoi(operatorArgv()[1]);
-  if ( nargc > 2 ) nskip   = atoi(operatorArgv()[2]);
+  int nargc  = operatorArgc();
+  int ndates = parameter2int(operatorArgv()[0]);
+  int noffset = 0, nskip = 0;
+  if ( nargc > 1 ) noffset = parameter2int(operatorArgv()[1]);
+  if ( nargc > 2 ) nskip   = parameter2int(operatorArgv()[2]);
 
   if ( cdoVerbose ) cdoPrint("nsets = %d, noffset = %d, nskip = %d", ndates, noffset, nskip);
 
-  lmean   = operfunc == func_mean || operfunc == func_avg;
-  lstd    = operfunc == func_std || operfunc == func_std1;
-  lvarstd = operfunc == func_std || operfunc == func_var || operfunc == func_std1 || operfunc == func_var1;
-  divisor = operfunc == func_std1 || operfunc == func_var1;
+  int lmean   = operfunc == func_mean || operfunc == func_avg;
+  int lstd    = operfunc == func_std || operfunc == func_std1;
+  int lvarstd = operfunc == func_std || operfunc == func_var || operfunc == func_std1 || operfunc == func_var1;
+  int divisor = operfunc == func_std1 || operfunc == func_var1;
 
-  streamID1 = streamOpenRead(cdoStreamName(0));
+  int streamID1 = streamOpenRead(cdoStreamName(0));
 
-  vlistID1 = streamInqVlist(streamID1);
-  vlistID2 = vlistDuplicate(vlistID1);
+  int vlistID1 = streamInqVlist(streamID1);
+  int vlistID2 = vlistDuplicate(vlistID1);
 
-  taxisID1 = vlistInqTaxis(vlistID1);
-  taxis_has_bounds = taxisHasBounds(taxisID1);
-  taxisID2 = taxisDuplicate(taxisID1);
+  int taxisID1 = vlistInqTaxis(vlistID1);
+  int taxisID2 = taxisDuplicate(taxisID1);
   vlistDefTaxis(vlistID2, taxisID2);
 
-  streamID2 = streamOpenWrite(cdoStreamName(1), cdoFiletype());
+  int streamID2 = streamOpenWrite(cdoStreamName(1), cdoFiletype());
 
   streamDefVlist(streamID2, vlistID2);
 
-  nvars    = vlistNvars(vlistID1);
-  nrecords = vlistNrecs(vlistID1);
+  int nvars    = vlistNvars(vlistID1);
+  int nrecords = vlistNrecs(vlistID1);
 
-  recVarID   = malloc(nrecords*sizeof(int));
-  recLevelID = malloc(nrecords*sizeof(int));
+  int *recVarID   = (int*) Malloc(nrecords*sizeof(int));
+  int *recLevelID = (int*) Malloc(nrecords*sizeof(int));
 
-  gridsize = vlistGridsizeMax(vlistID1);
+  dtlist_type *dtlist = dtlist_new();
+  dtlist_set_stat(dtlist, timestat_date);
+  dtlist_set_calendar(dtlist, taxisInqCalendar(taxisID1));
 
+  int gridsize = vlistGridsizeMax(vlistID1);
+
+  field_t field;
   field_init(&field);
-  field.ptr = malloc(gridsize*sizeof(double));
+  field.ptr = (double*) Malloc(gridsize*sizeof(double));
 
-  vars1 = field_malloc(vlistID1, FIELD_PTR);
-  samp1 = field_malloc(vlistID1, FIELD_NONE);
-  if ( lvarstd )
-    vars2 = field_malloc(vlistID1, FIELD_PTR);
+  field_t **samp1 = field_malloc(vlistID1, FIELD_NONE);
+  field_t **vars1 = field_malloc(vlistID1, FIELD_PTR);
+  field_t **vars2 = NULL;
+  if ( lvarstd ) vars2 = field_malloc(vlistID1, FIELD_PTR);
 
   for ( tsID = 0; tsID < noffset; tsID++ )
     {
@@ -140,13 +128,13 @@ void *Timselstat(void *argument)
 	}
     }
 
+  int otsID   = 0;
   if ( tsID < noffset )
     {
       cdoWarning("noffset is larger than number of timesteps!");
       goto LABEL_END;
     }
 
-  otsID   = 0;
   while ( TRUE )
     {
       for ( nsets = 0; nsets < ndates; nsets++ )
@@ -154,21 +142,7 @@ void *Timselstat(void *argument)
 	  nrecs = streamInqTimestep(streamID1, tsID);
 	  if ( nrecs == 0 ) break;
 
-	  vdate = taxisInqVdate(taxisID1);
-	  vtime = taxisInqVtime(taxisID1);
-
-	  if ( taxis_has_bounds )
-	    {
-	      taxisInqVdateBounds(taxisID1, &date_lb, &date_ub);
-	      taxisInqVtimeBounds(taxisID1, &time_lb, &time_ub);
-	      if ( nsets == 0 )
-		{
-		  vdate_lb = date_lb;
-		  vtime_lb = time_lb;
-		}
-	      vdate_ub = date_ub;
-	      vtime_ub = time_ub;
-	    }
+	  dtlist_taxisInqTimestep(dtlist, taxisID1, nsets);
 
 	  for ( recID = 0; recID < nrecs; recID++ )
 	    {
@@ -185,12 +159,12 @@ void *Timselstat(void *argument)
 	      if ( nsets == 0 )
 		{
 		  streamReadRecord(streamID1, vars1[varID][levelID].ptr, &nmiss);
-		  vars1[varID][levelID].nmiss = nmiss;
+		  vars1[varID][levelID].nmiss = (size_t)nmiss;
 
 		  if ( nmiss > 0 || samp1[varID][levelID].ptr )
 		    {
 		      if ( samp1[varID][levelID].ptr == NULL )
-			samp1[varID][levelID].ptr = malloc(gridsize*sizeof(double));
+			samp1[varID][levelID].ptr = (double*) Malloc(gridsize*sizeof(double));
 
 		      for ( i = 0; i < gridsize; i++ )
 			if ( DBL_IS_EQUAL(vars1[varID][levelID].ptr[i],
@@ -202,7 +176,8 @@ void *Timselstat(void *argument)
 		}
 	      else
 		{
-		  streamReadRecord(streamID1, field.ptr, &field.nmiss);
+		  streamReadRecord(streamID1, field.ptr, &nmiss);
+                  field.nmiss   = (size_t)nmiss;
 		  field.grid    = vars1[varID][levelID].grid;
 		  field.missval = vars1[varID][levelID].missval;
 
@@ -210,7 +185,7 @@ void *Timselstat(void *argument)
 		    {
 		      if ( samp1[varID][levelID].ptr == NULL )
 			{
-			  samp1[varID][levelID].ptr = malloc(gridsize*sizeof(double));
+			  samp1[varID][levelID].ptr = (double*) Malloc(gridsize*sizeof(double));
 			  for ( i = 0; i < gridsize; i++ )
 			    samp1[varID][levelID].ptr[i] = nsets;
 			}
@@ -241,8 +216,6 @@ void *Timselstat(void *argument)
 		  farmoq(&vars2[varID][levelID], vars1[varID][levelID]);
 	      }
 
-	  vdate0 = vdate;
-	  vtime0 = vtime;
 	  tsID++;
 	}
 
@@ -252,11 +225,11 @@ void *Timselstat(void *argument)
 	for ( varID = 0; varID < nvars; varID++ )
 	  {
 	    if ( vlistInqVarTsteptype(vlistID1, varID) == TSTEP_CONSTANT ) continue;
-	    nlevel   = zaxisInqSize(vlistInqVarZaxis(vlistID1, varID));
+	    nlevel = zaxisInqSize(vlistInqVarZaxis(vlistID1, varID));
 	    for ( levelID = 0; levelID < nlevel; levelID++ )
 	      {
 		if ( samp1[varID][levelID].ptr == NULL )
-		  farcmul(&vars1[varID][levelID], 1.0/nsets);
+		  farcdiv(&vars1[varID][levelID], (double)nsets);
 		else
 		  fardiv(&vars1[varID][levelID], samp1[varID][levelID]);
 	      }
@@ -265,33 +238,27 @@ void *Timselstat(void *argument)
 	for ( varID = 0; varID < nvars; varID++ )
 	  {
 	    if ( vlistInqVarTsteptype(vlistID1, varID) == TSTEP_CONSTANT ) continue;
-	    nlevel   = zaxisInqSize(vlistInqVarZaxis(vlistID1, varID));
+	    nlevel = zaxisInqSize(vlistInqVarZaxis(vlistID1, varID));
 	    for ( levelID = 0; levelID < nlevel; levelID++ )
 	      {
 		if ( samp1[varID][levelID].ptr == NULL )
 		  {
 		    if ( lstd )
-		      farcstdx(&vars1[varID][levelID], vars2[varID][levelID], nsets, divisor);
+		      farcstd(&vars1[varID][levelID], vars2[varID][levelID], nsets, divisor);
 		    else
-		      farcvarx(&vars1[varID][levelID], vars2[varID][levelID], nsets, divisor);
+		      farcvar(&vars1[varID][levelID], vars2[varID][levelID], nsets, divisor);
 		  }
 		else
 		  {
 		    if ( lstd )
-		      farstdx(&vars1[varID][levelID], vars2[varID][levelID], samp1[varID][levelID], divisor);
+		      farstd(&vars1[varID][levelID], vars2[varID][levelID], samp1[varID][levelID], divisor);
 		    else
-		      farvarx(&vars1[varID][levelID], vars2[varID][levelID], samp1[varID][levelID], divisor);
+		      farvar(&vars1[varID][levelID], vars2[varID][levelID], samp1[varID][levelID], divisor);
 		  }
 	      }
 	  }
 
-      taxisDefVdate(taxisID2, vdate0);
-      taxisDefVtime(taxisID2, vtime0);
-      if ( taxis_has_bounds )
-	{
-	  taxisDefVdateBounds(taxisID2, vdate_lb, vdate_ub);
-	  taxisDefVtimeBounds(taxisID2, vtime_lb, vtime_ub);
-	}
+      dtlist_stat_taxisDefTimestep(dtlist, taxisID2, nsets);
       streamDefTimestep(streamID2, otsID);
 
       for ( recID = 0; recID < nrecords; recID++ )
@@ -302,7 +269,7 @@ void *Timselstat(void *argument)
 	  if ( otsID && vlistInqVarTsteptype(vlistID1, varID) == TSTEP_CONSTANT ) continue;
 
 	  streamDefRecord(streamID2, varID, levelID);
-	  streamWriteRecord(streamID2, vars1[varID][levelID].ptr,  vars1[varID][levelID].nmiss);
+	  streamWriteRecord(streamID2, vars1[varID][levelID].ptr, (int)vars1[varID][levelID].nmiss);
 	}
 
       if ( nrecs == 0 ) break;
@@ -325,15 +292,17 @@ void *Timselstat(void *argument)
   field_free(samp1, vlistID1);
   if ( lvarstd ) field_free(vars2, vlistID1);
 
-  if ( field.ptr ) free(field.ptr);
+  dtlist_delete(dtlist);
 
-  if ( recVarID   ) free(recVarID);
-  if ( recLevelID ) free(recLevelID);
+  if ( field.ptr ) Free(field.ptr);
+
+  if ( recVarID   ) Free(recVarID);
+  if ( recLevelID ) Free(recLevelID);
 
   streamClose(streamID2);
   streamClose(streamID1);
 
   cdoFinish();
 
-  return (0);
+  return 0;
 }
