@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2015 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
+  Copyright (C) 2003-2016 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -50,12 +50,12 @@ void trms(field_t field1, field_t field2, double *dp, field_t *field3)
     for ( i = 0; i < len; i++ ) 
       {
 	wp = w[i]*dp[k*len+i];
-	rsum  = ADD(rsum, MUL(wp, MUL(SUB(array2[k*len+i], array1[k*len+i]),
-				      SUB(array2[k*len+i], array1[k*len+i]))));
-	rsumw = ADD(rsumw, wp);
+	rsum  = ADDMN(rsum, MULMN(wp, MULMN( SUBMN(array2[k*len+i], array1[k*len+i]),
+				      SUBMN(array2[k*len+i], array1[k*len+i]))));
+	rsumw = ADDMN(rsumw, wp);
       }
 
-  ravg = SQRT(DIV(rsum, rsumw));
+  ravg = SQRTMN( DIVMN(rsum, rsumw));
 
   if ( DBL_IS_EQUAL(ravg, missval1) ) rnmiss++;
 
@@ -170,19 +170,19 @@ void *Trms(void *argument)
 
   streamDefVlist(streamID3, vlistID3);
 
-  vardata1 = (double**) malloc(nvars*sizeof(double*));
-  vardata2 = (double**) malloc(nvars*sizeof(double*));
+  vardata1 = (double**) Malloc(nvars*sizeof(double*));
+  vardata2 = (double**) Malloc(nvars*sizeof(double*));
 
   gridsize = gridInqSize(vlistInqVarGrid(vlistID1, pvarID));
   nlevel   = vctsize/2 - 1;
-  dp = (double*) malloc(gridsize*nlevel*sizeof(double));
+  dp = (double*) Malloc(gridsize*nlevel*sizeof(double));
 
   for ( varID = 0; varID < nvars; varID++ )
     {
       gridsize = gridInqSize(vlistInqVarGrid(vlistID1, varID));
       nlevel   = zaxisInqSize(vlistInqVarZaxis(vlistID1, varID));
-      vardata1[varID] = (double*) malloc(gridsize*nlevel*sizeof(double));
-      vardata2[varID] = (double*) malloc(gridsize*nlevel*sizeof(double));
+      vardata1[varID] = (double*) Malloc(gridsize*nlevel*sizeof(double));
+      vardata2[varID] = (double*) Malloc(gridsize*nlevel*sizeof(double));
     }
 
   field_init(&field1);
@@ -192,7 +192,7 @@ void *Trms(void *argument)
   lim = vlistGridsizeMax(vlistID1);
   field1.weight = NULL;
   if ( needWeights )
-    field1.weight = (double*) malloc(lim*sizeof(double));
+    field1.weight = (double*) Malloc(lim*sizeof(double));
 
   field2.weight = NULL;
 
@@ -282,19 +282,19 @@ void *Trms(void *argument)
 
   vlistDestroy(vlistID3);
 
-  if ( field1.weight ) free(field1.weight);
+  if ( field1.weight ) Free(field1.weight);
 
   for ( varID = 0; varID < nvars; varID++ )
     {
-      free(vardata1[varID]);
-      free(vardata2[varID]);
+      Free(vardata1[varID]);
+      Free(vardata2[varID]);
     }
 
-  free(vardata1);
-  free(vardata2);
-  free(dp);
+  Free(vardata1);
+  Free(vardata2);
+  Free(dp);
 
   cdoFinish();
 
-  return (0);
+  return 0;
 }
