@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2015 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
+  Copyright (C) 2003-2016 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -62,11 +62,11 @@ void *Writerandom(void *argument)
 
       streamDefTimestep(streamID2, tsID);
 
-      recdata    = (double**) malloc(nrecs*sizeof(double*));
-      recvarID   = (int*) malloc(nrecs*sizeof(int));
-      reclevelID = (int*) malloc(nrecs*sizeof(int));
-      recnmiss   = (int*) malloc(nrecs*sizeof(int));
-      recindex   = (int*) malloc(nrecs*sizeof(int));
+      recdata    = (double**) Malloc(nrecs*sizeof(double*));
+      recvarID   = (int*) Malloc(nrecs*sizeof(int));
+      reclevelID = (int*) Malloc(nrecs*sizeof(int));
+      recnmiss   = (int*) Malloc(nrecs*sizeof(int));
+      recindex   = (int*) Malloc(nrecs*sizeof(int));
 
       for ( recID = 0; recID < nrecs; recID++ )
 	{
@@ -74,7 +74,7 @@ void *Writerandom(void *argument)
 	  gridsize = gridInqSize(vlistInqVarGrid(vlistID1, varID));
 	  recvarID[recID] = varID;
 	  reclevelID[recID] = levelID;
-	  recdata[recID] = (double*) malloc(gridsize*sizeof(double));
+	  recdata[recID] = (double*) Malloc(gridsize*sizeof(double));
 	  streamReadRecord(streamID1, recdata[recID], &recnmiss[recID]);
 	}
 
@@ -82,7 +82,7 @@ void *Writerandom(void *argument)
 
       for ( rindex = nrecs-1; rindex >= 0; rindex-- )
 	{
-	  index = (int) (rindex*1.0*rand()/(RAND_MAX+1.0));
+	  index = (int) (rindex*((double)rand())/((double)RAND_MAX));
 	  /*	printf("rindex %d %d\n", rindex, index); */
 	  ipos = -1;
 	  for ( recID = 0; recID < nrecs; recID++ )
@@ -114,13 +114,13 @@ void *Writerandom(void *argument)
 	  streamWriteRecord(streamID2, recdata[rindex], recnmiss[rindex]);
 	}
 
-      for ( recID = 0; recID < nrecs; recID++ ) free(recdata[recID]);
+      for ( recID = 0; recID < nrecs; recID++ ) Free(recdata[recID]);
 
-      free(recdata);
-      free(recvarID);
-      free(reclevelID);
-      free(recnmiss);
-      free(recindex);
+      Free(recdata);
+      Free(recvarID);
+      Free(reclevelID);
+      Free(recnmiss);
+      Free(recindex);
 
       tsID++;
     }
@@ -130,5 +130,5 @@ void *Writerandom(void *argument)
 
   cdoFinish();
 
-  return (0);
+  return 0;
 }
