@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2015 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
+  Copyright (C) 2003-2016 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -71,6 +71,7 @@ void *Yhourarith(void *argument)
   int vlistID1, vlistID2, vlistID3;
   int taxisID1, taxisID2, taxisID3;
   int vdate, vtime;
+  int nmiss;
   int houroy;
   field_t field1, field2;
   int **varnmiss2[MAX_HOUR];
@@ -99,8 +100,8 @@ void *Yhourarith(void *argument)
 
   field_init(&field1);
   field_init(&field2);
-  field1.ptr = (double*) malloc(gridsize*sizeof(double));
-  field2.ptr = (double*) malloc(gridsize*sizeof(double));
+  field1.ptr = (double*) Malloc(gridsize*sizeof(double));
+  field2.ptr = (double*) Malloc(gridsize*sizeof(double));
 
   taxisID1 = vlistInqTaxis(vlistID1);
   taxisID2 = vlistInqTaxis(vlistID2);
@@ -124,15 +125,15 @@ void *Yhourarith(void *argument)
       houroy = hour_of_year(vdate, vtime);
       if ( vardata2[houroy] != NULL ) cdoAbort("Hour of year %d already allocatd!", houroy);
 
-      vardata2[houroy]  = (double **) malloc(nvars*sizeof(double *));
-      varnmiss2[houroy] = (int **) malloc(nvars*sizeof(int *));
+      vardata2[houroy]  = (double **) Malloc(nvars*sizeof(double *));
+      varnmiss2[houroy] = (int **) Malloc(nvars*sizeof(int *));
 
       for ( varID = 0; varID < nvars; varID++ )
 	{
 	  gridsize = gridInqSize(vlistInqVarGrid(vlistID2, varID));
 	  nlev     = zaxisInqSize(vlistInqVarZaxis(vlistID2, varID));
-	  vardata2[houroy][varID]  = (double*) malloc(nlev*gridsize*sizeof(double));
-	  varnmiss2[houroy][varID] = (int*) malloc(nlev*sizeof(int));
+	  vardata2[houroy][varID]  = (double*) Malloc(nlev*gridsize*sizeof(double));
+	  varnmiss2[houroy][varID] = (int*) Malloc(nlev*sizeof(int));
 	}
 
       for ( recID = 0; recID < nrecs; recID++ )
@@ -142,8 +143,8 @@ void *Yhourarith(void *argument)
 	  gridsize = gridInqSize(vlistInqVarGrid(vlistID2, varID));
 	  offset   = gridsize*levelID;
 
-	  streamReadRecord(streamID2, vardata2[houroy][varID]+offset, &field2.nmiss);
-	  varnmiss2[houroy][varID][levelID] = field2.nmiss;
+	  streamReadRecord(streamID2, vardata2[houroy][varID]+offset, &nmiss);
+	  varnmiss2[houroy][varID][levelID] = nmiss;
 	}
 
       tsID++;
@@ -166,23 +167,22 @@ void *Yhourarith(void *argument)
       for ( recID = 0; recID < nrecs; recID++ )
 	{
 	  streamInqRecord(streamID1, &varID, &levelID);
-	  streamReadRecord(streamID1, field1.ptr, &field1.nmiss);
+	  streamReadRecord(streamID1, field1.ptr, &nmiss);
+          field1.nmiss = (size_t) nmiss;
+	  field1.grid    = vlistInqVarGrid(vlistID1, varID);
+	  field1.missval = vlistInqVarMissval(vlistID1, varID);
 
 	  gridsize = gridInqSize(vlistInqVarGrid(vlistID2, varID));
 	  offset   = gridsize*levelID;
 	  memcpy(field2.ptr, vardata2[houroy][varID]+offset, gridsize*sizeof(double));
 	  field2.nmiss   = varnmiss2[houroy][varID][levelID];
-
-	  field1.grid    = vlistInqVarGrid(vlistID1, varID);
-	  field1.missval = vlistInqVarMissval(vlistID1, varID);
-
 	  field2.grid    = vlistInqVarGrid(vlistID2, varID);
 	  field2.missval = vlistInqVarMissval(vlistID2, varID);
 
 	  farfun(&field1, field2, operfunc);
 
 	  streamDefRecord(streamID3, varID, levelID);
-	  streamWriteRecord(streamID3, field1.ptr, field1.nmiss);
+	  streamWriteRecord(streamID3, field1.ptr, (int)field1.nmiss);
 	}
 
       tsID++;
@@ -197,18 +197,18 @@ void *Yhourarith(void *argument)
       {
 	for ( varID = 0; varID < nvars; varID++ )
 	  {
-	    free(vardata2[houroy][varID]);
-	    free(varnmiss2[houroy][varID]);
+	    Free(vardata2[houroy][varID]);
+	    Free(varnmiss2[houroy][varID]);
 	  }
 
-	free(vardata2[houroy]);
-	free(varnmiss2[houroy]);
+        Free(vardata2[houroy]);
+        Free(varnmiss2[houroy]);
       }
 
-  if ( field1.ptr ) free(field1.ptr);
-  if ( field2.ptr ) free(field2.ptr);
+  if ( field1.ptr ) Free(field1.ptr);
+  if ( field2.ptr ) Free(field2.ptr);
 
   cdoFinish();
 
-  return (0);
+  return 0;
 }
